.. _install-server:

Install Inmanta
***************

This page explains how to install the Inmanta orchestrator software and setup an orchestration server. Regardless what platform
you installed it on, Inmanta requires at least the latest Python 3.6 or 3.7 and git.

.. include:: ./install-server/install-server.inc
.. include:: ./install-server/configure-postgres.inc
.. include:: ./install-server/configure-server.inc
